use std::time::Duration;

#[cfg(feature = "f32")]
pub type Float = f32;
#[cfg(feature = "f32")]
pub use std::f32 as floats;
#[cfg(not(feature = "f32"))]
pub type Float = f64;
#[cfg(not(feature = "f32"))]
pub use std::f64 as floats;


#[derive(Debug, Copy, Clone, Eq, PartialEq)]
pub(crate) enum Mode {
    Once,
    RepeatFrom(usize),
    PingPong
}

impl Default for Mode {
    fn default() -> Self {
        Self::RepeatFrom(0usize)
    }
}

pub struct Frame {
    pub index: usize,
    pub duration: Duration
}

impl Frame {
    pub fn new(index: usize, duration: Duration) -> Self {
        assert!(!duration.is_zero(), "must be a non-zero duration");
        Self { index, duration }
    }
}

pub struct Animation {
    pub(crate) frames: Vec<Frame>,
    pub(crate) mode: Mode
}

#[cfg(test)]
mod tests {
    se rstest::rstest;
    use super::Float;

    #[rstest]
    fn test(#[values(0.0, -1.0)] time: Float) {
    }
}

