use assets::{ldtk::WorldConfig, AssetPlugin};
use bevy::prelude::*;
use bevy_smooth_pixel_camera::PixelCameraPlugin;
use bevy_xpbd_2d::math::{Scalar, Vector};
use camera::CameraPlugin;
use debug::DebugPlugin;
use level::LevelPlugin;
use physics::PhysicsPlugin;
use player::PlayerPlugin;

mod assets;
mod camera;
mod debug;
mod level;
mod physics;
mod player;
mod animation;

#[derive(States, Default, Debug, Clone, PartialEq, Eq, Hash)]
pub enum GameState {
    MainMenu,
    #[default]
    Loading,
    Playing,
}

pub const GRAVITY: Scalar = 9.81;
pub const GRAVITY_VECTOR: Vector = Vector { x: 0., y: -GRAVITY };

pub struct GamePlugin;
impl Plugin for GamePlugin {
    fn build(&self, app: &mut bevy::prelude::App) {
        app.add_plugins(DefaultPlugins.set(ImagePlugin::default_nearest()))
            .add_plugins(PixelCameraPlugin)
            .add_plugins((
                AssetPlugin,
                PhysicsPlugin,
                LevelPlugin,
                AnimationPlugin,
                PlayerPlugin,
                CameraPlugin,
            ))
            .init_state::<GameState>()
            .insert_resource(WorldConfig {
                path: "level.ldtk".to_string(),
            });

        #[cfg(debug_assertions)]
        app.add_plugins(DebugPlugin);
    }
}

